@@ -12,10 +12,10 @@ from sqlalchemy.engine import Connection
 
 class DatabaseExporter(BaseExporter):
     config_schema = {
-        "database_url": Field(
+        "connection_uri": Field(
             StringSource,
             is_required=True,
-            description="The sqlalchemy connection uri",
+            description="The SqlAlchemy connection uri. (postgresql://user:password@host:port/database)",
         ),
         "table_name": Field(
             str,
