@@ -1,27 +1,32 @@
-from dagster import ModeDefinition, PipelineExecutionResult, execute_pipeline, pipeline
-from dagster.core.execution.results import SolidExecutionResult
+from dagster import (
+    ModeDefinition,
+    OpExecutionContext,
+    PipelineExecutionResult,
+    execute_pipeline,
+    pipeline,
+)
 from dask.dataframe import DataFrame as DaskDataFrame
 from pandas import DataFrame
 from qdk import DataFrameLoader, YakeTransformer, qdk_io_manager
 
 from ..utils.dataframe import CSVStoreDataFrame
 
-loader_solid = DataFrameLoader.to_solid(
+loader_op = DataFrameLoader.to_op(
     name="loader",
 )
 
-keyword_solid = YakeTransformer.to_solid(
+keyword_op = YakeTransformer.to_op(
     name="keyword",
 )
 
 
 @pipeline(mode_defs=[ModeDefinition(resource_defs={"io_manager": qdk_io_manager})])
 def nlp_pipeline():
-    df = loader_solid()
-    keyword = keyword_solid(df)
+    df = loader_op()
+    keyword = keyword_op(df)
 
 
-def run_pipeline(tmpdir: str, use_dask: bool) -> SolidExecutionResult:
+def run_pipeline(tmpdir: str, use_dask: bool) -> OpExecutionContext:
     # Create a temporary dataframe and store it in the temp directory
     df_storer = CSVStoreDataFrame()
     df_path = df_storer.store_dataframe(tmpdir)
@@ -30,7 +35,7 @@ def run_pipeline(tmpdir: str, use_dask: bool) -> SolidExecutionResult:
     result = execute_pipeline(
         nlp_pipeline,
         run_config={
-            "solids": {
+            "ops": {
                 "loader": {
                     "config": {
                         "uri": df_path,
